@@ -169,7 +169,8 @@ vec=pmax(seq(from=AnfangsRadius-1,by=-1,length.out = HeuristischerParameter),1)
   Umap=calcUmatrixToroid(wts)
 LCnew=c(dim(wts)[1],dim(wts)[2])
 if(PlotIt){
-	plotTopographicMap(Umap,BMUs)
+  requireNamespace("GeneralizedUmatrix")
+  GeneralizedUmatrix::plotTopographicMap(Umap,BMUs)
 }
 return(list(Bestmatches=BMUs,Umatrix=Umap,WeightsOfNeurons=wts,GridPoints=Points,LC=LCnew))
 }
\ No newline at end of file
